require("./env");

var vows = require('vows');
var assert = require('assert');

var suite = vows.describe('Geo choropleth chart');

function buildChart(id) {
    var div = d3.select("body").append("div").attr("id", id);
    div.append("a").attr("class", "reset").style("display", "none");
    div.append("span").attr("class", "filter").style("display", "none");
    var chart = dc.geoChoroplethChart("#" + id);
    chart.dimension(stateDimension)
        .group(stateValueSumGroup)
        .width(990)
        .height(600)
        .dimension(stateDimension)
        .group(stateValueSumGroup)
        .colors(["#ccc", "#E2F2FF", "#C4E4FF", "#9ED2FF", "#81C5FF", "#6BBAFF", "#51AEFF", "#36A2FF", "#1E96FF", "#0089FF"])
        .colorDomain([0, 155])
        .overlayGeoJson(geoJson.features, "state", function (d) {
            return d.properties.name;
        })
        .overlayGeoJson(geoJson2.features, "county")
        .transitionDuration(0)
        .title(function (d) {
            return d.key + " : " + (d.value ? d.value : 0);
        });
    chart.render();
    return chart;
}

function buildChartWithCustomProjection(id) {
    var div = d3.select("body").append("div").attr("id", id);
    div.append("a").attr("class", "reset").style("display", "none");
    div.append("span").attr("class", "filter").style("display", "none");
    var chart = dc.geoChoroplethChart("#" + id);
    chart.dimension(districtDimension)
        .group(districtValueEnrollGroup)
        .projection(d3.geo.mercator()
            .scale(26778)
            .translate([8227, 3207]))
        .width(990)
        .height(600)
        .colors(["#ccc", "#E2F2FF", "#C4E4FF", "#9ED2FF", "#81C5FF", "#6BBAFF", "#51AEFF", "#36A2FF", "#1E96FF", "#0089FF"])
        .colorDomain([0, 155])
        .overlayGeoJson(geoJson3.features, "district", function (d) {
            return d.properties.NAME;
        })
        .transitionDuration(0)
        .title(function (d) {
            return d.key + " : " + (d.value ? d.value : 0);
        });
    chart.render();
    return chart;
}


suite.addBatch({
    'creation': {
        topic: function () {
            return buildChart("choropleth-chart");
        },
        'should return not null': function (chart) {
            assert.isNotNull(chart);
        },
        'svg is created': function (chart) {
            assert.isNotEmpty(chart.selectAll("svg"));
        },
        'geo layer0 g is created': function (chart) {
            assert.isNotEmpty(chart.selectAll("g.layer0"));
        },
        'correct number of states should be generated': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state")[0].length, 52);
        },
        'correct css class should be set [Alaska]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state")[0][1].getAttribute("class"), "state alaska");
        },
        'correct title should be set [Alaska]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state title")[0][1].innerHTML, "Alaska : 0");
        },
        'correct color filling should be set [Alaska]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state path")[0][1].getAttribute("fill"), "#ccc");
        },
        'correct state boundary should be rendered [Alaska]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state path")[0][1].getAttribute("d"), "M244.90878107260022,435.44513195370473L244.37332874147907,433.7977234467205L245.9627664793218,434.2053050073433L246.52691135177687,435.9031119503561L245.02629619735362,436.3370291223139ZM242.33216429159268,433.0858737472198L243.86229592444712,433.77836626837154L244.05528939527443,435.70693457290884L243.34751020047798,435.3344763473848ZM231.90787247740437,426.0749915758713L233.09422259665982,425.3107371880525L233.8062421814242,425.4389180176249L234.2526568428743,426.9364801824189L233.25224018366575,427.7470781423941L231.84412012018635,427.29061992290553ZM228.9723494550126,428.32277722682466L231.41584284995275,427.66160925991755L232.7931400190439,429.25849782072453L236.00449952546128,430.30746892125273L237.35335452266847,431.2204860116535L237.87489324650886,432.2453618940241L238.52952148827384,432.2075434754089L239.2219286562351,433.53306715447343L240.7784643142858,434.4745362967411L241.43493772108093,435.6267575934289L241.89750910685055,434.98011094488254L242.5885888544914,435.8019761839088L244.37682823016243,439.4627538317893L244.3595160877741,440.47595856324153L242.74528669476663,441.00673236503735L241.4871513085726,439.30603186282383L241.01333796909907,439.702833856593L239.2763698270861,438.77305503145647L239.15095573933093,439.390734948023L238.01051044411807,439.3225467427285L238.7760275429375,440.6786270161199L239.49328390344658,439.9297850521963L240.29685328266166,440.20486820359145L240.87313886687713,442.2681841547593L239.71718444011788,442.52054420940397L237.0432221499254,440.73723269893105L236.0491339258408,439.66491171067867L235.57700355442864,438.3071391564139L234.35742895501062,438.94952025036673L233.9331919300017,437.9453423371988L234.84927674940752,437.4322480206298L235.4245678942592,436.1257519236764L234.32930068313348,434.72172546878573L233.06246259406953,434.88647845762114L231.8100191131846,432.42433683026525L230.86013200782185,431.32954188126257L230.4700857131566,432.5524819722564L229.5757931172376,431.24604521797403L230.0822256454035,430.22395060624535L228.74724514241288,428.85319720349173ZM231.41869390938967,436.32491641817865L232.73221841160967,436.52115138869044L233.114774788176,435.4252983878073L233.9879562718538,435.4912296519543L233.8451824818529,437.234969624595L232.4972717506591,437.30453386891304ZM224.9711835450502,423.3921435849817L223.82671925223767,422.7455027686566L224.42581892461644,421.7514189256491L227.64536878559062,421.4602512563391L228.88406865317114,420.8693771627852L230.54604335295653,422.2817940160105L232.82826221625388,423.0445763035241L233.1382827919205,424.22598402058804L232.52181844294748,425.1835980673402L231.21867250478877,425.4333717262091L230.67003360853565,426.4809329251806L229.32600386966175,426.552727024353L228.2217717818872,427.51620686455715L227.0063335416017,425.3464605072587L226.5013930264307,423.81342990487497L225.52567183951973,424.1577491348587ZM225.66469008033553,428.20360386024447L224.6291510008461,427.7584820926818L223.19200667477477,426.4822419511172L222.6080017856624,425.29268516151535L223.0072537182769,424.447899209188L223.91224795350672,424.76103246921537L223.64252218703888,423.6913202839123L226.44918605969178,424.5826783138655L227.36085213661133,426.19477056489677L226.72173740847668,426.71007812731443L227.04673702798146,428.8144434915829L227.79440219618493,429.1262337171614L228.07101879304918,431.6230538121031L227.04743167005125,431.48591011309236L227.4963487576554,432.9157106763232L226.68031858145258,432.4432153521184L225.24885597259276,429.8635607908693ZM223.65273670161505,431.2530614166627L223.92474256871762,432.44363311387383L222.92931819405678,432.09936295127807L219.2174651725023,428.562858036316L217.45875695400736,427.76850381582017L217.50042985959027,426.58063168416766L216.04909235147392,424.30775592116504L213.89818153778424,422.8571770943339L214.55965239386606,420.3832513309558L215.502128842435,420.94217857694525L216.98612570115944,421.10146700785094L218.14565380498664,420.765930889168L218.79089378557953,422.3038070616684L221.91824674543471,426.93447736108226ZM215.67617081383156,412.5237629608863L217.71057412648256,412.57185948194706L218.67276649076956,412.05505256554966L218.9221694227095,412.82328290077373L221.47708152198672,414.8814249553561L220.28823832892516,414.8743322921364L220.40596805475175,415.8830456203498L222.07812197158347,416.8113754393263L223.43188029807294,419.1137456181509L222.58228849689803,420.2113828197166L222.55962623641608,421.2151774031105L221.46225007313078,423.71013245465315L220.89200653995016,423.8780288304274L219.91126248282913,422.1036336771556L219.8338162912557,420.8334143602618L218.99692189872638,419.2486733029423L217.55787968781658,417.4711632386235L217.24372020430025,416.3578223186104L215.80315696543866,413.8980448498006L214.68374796076773,413.04314031204024L213.72497136558448,411.1950264312635ZM213.14792922144568,423.57454864463614L213.8980707259366,423.2882505468949L215.35878483177663,424.75959825297355L215.48549250404002,426.12756923774566L214.39488530081948,426.85229407128804L213.83284436493767,424.8518185282353ZM207.70521205421483,415.79097918180116L209.2764415110473,415.2620286224078L209.96195614094498,414.0166812731836L211.87717626781648,414.6368197839297L211.58427220221515,416.2293917422868L212.05281951876157,416.60394366803064L212.226861485094,414.87161637999066L214.18781555668895,414.6618613791551L215.59607093374763,415.34258599247937L215.79271462535593,417.49185615723195L216.30996991889782,417.47279216367076L217.92700304448059,419.80077766554075L216.70291566334942,420.7185962180614L213.34489148784263,419.61973600817305L214.25818412500476,421.73305335772125L213.78295571655772,422.9013283169709L212.68886319560224,422.88784049862556L211.60424975435134,421.7614469667843L210.16966852218212,421.2565521467826L208.63646281712502,419.67991279594753L207.26179034935444,419.2071483629736L206.74209898336505,417.620722975308L207.25115377209193,416.8192476587052L206.9766880923288,415.3868994229514ZM146.56184838189267,411.3963834338522L144.91082853667743,414.4138220976422L144.93554667242398,415.46398416577654L143.31207552040343,416.47089650656164L143.38525815408673,414.8179446267785L144.95577011460813,412.82270251787793L145.77766917339392,410.78742504579975ZM143.36883990020326,407.967445648468L143.498638475463,410.16945875890633L143.18830374107702,412.51215768000657L142.0467953316788,411.96208741460066L142.410209768974,409.2603928206129ZM123.77879247951172,308.9418662300692L124.23061687816181,309.315843394657L126.16268910931981,309.4043817582685L127.07943946862716,308.9358093159159L128.41791559293392,308.66410159493114L129.95294476904093,308.7459105762854L130.75830941375142,308.34281341320127L131.77205184922053,308.9869098554036L133.49711779129473,309.5837663490555L135.59045603367485,309.3312521553747L136.02337414240722,308.6490672783543L137.299108786504,307.99313267396076L137.70313621959238,307.1393183682876L139.13812893462847,306.6638290990642L139.24360591375245,307.1603541199553L140.03973188212467,306.66599179741957L142.02831621415885,306.96132815966223L143.57971182576705,307.8878117670264L144.8844667294295,308.17391222915535L145.2869844867201,308.6480613340283L146.363853780379,308.4636426285896L147.6160503768035,309.1051392134266L147.98222691749822,309.6464319265649L148.4435595771073,308.98364404825554L149.29252079832554,309.14736509024294L176.85496477879178,402.84795538097114L179.4101803238705,402.98770186081936L179.44201819908432,402.01573895366255L182.24295575255604,402.5415411630447L183.177287778844,400.4992950788735L186.11205347898823,399.3768993653663L186.44378648754213,402.23530754967453L187.50612028029556,402.91905490737383L189.50614254954206,403.23023710966856L190.36018996542956,404.52355234865627L197.25186063264675,408.00699921809587L199.22094248386418,411.03619512032776L199.8104210246058,409.78880567077454L201.45523701686488,407.4224170047072L202.673435452898,406.915365792369L202.81109990268993,405.5147306070364L202.09746986268698,403.75326721502677L202.9683661845441,403.42990221112893L202.60175609808718,401.7848006121326L204.0003960601925,400.828018811447L205.7718765979269,398.608498866598L208.90283115188524,400.04248804017243L209.23618526490887,401.51996184556845L210.3279484458731,402.697903626516L211.73103171364752,402.5108917036848L214.17464698252067,403.9459067355132L214.3037070041329,404.57682352169047L215.4973182412578,405.39592216205733L218.07712132478366,405.82700377494837L223.78756011700227,409.97666736054134L224.92207621031864,411.24310771333876L226.61942034491256,412.26539870724514L229.6137269934722,414.85047191031504L232.4246819349155,416.9412673252615L232.34098476928992,418.3616166621832L234.17625963604104,418.04876663299467L234.52794479788247,419.9062938140962L236.17623491964392,419.9858727823205L237.2224971707238,421.84648937943825L238.52350512772819,421.1299141687017L242.0194585460847,421.9234154327845L243.7977252983348,421.535292183799L245.07205466136233,422.07702527353854L245.9998767769538,421.9541998552098L246.6750256288907,422.7776291169341L248.49706563450917,422.22105924502375L249.5658716225465,423.1072678042674L249.80997860246,425.6042619077256L250.77463840791864,427.3058196549067L252.93609100266818,429.8298123908346L252.69783941932252,430.8377141987911L252.6639405962709,434.1003446875309L251.66503162981599,436.9249194495941L250.66157331392472,436.1936610039438L250.08943219669644,436.8423080337468L248.65868476875133,435.1055858535425L248.4194095929002,434.20450077324574L247.36480074186838,433.4934971202496L248.1229816107981,431.8728620517212L247.59807229110845,431.6752959170059L246.96025956960924,433.5548631267385L245.89251226874865,433.03742150361074L245.33676110711312,433.8616138251426L242.1312156583022,432.7988052332739L241.8572086072035,430.15073497937897L240.79725516996695,431.57408656687414L241.25537922907003,432.7525233346611L239.73218387132744,432.3647512384906L239.00589574184932,431.3685139051199L239.23386542506918,429.8212785753037L238.46069113069092,428.72026327695414L237.8471994806755,430.1867288025147L235.84125605503561,428.49813517959774L235.38101676185738,429.2012824363678L234.19056327736791,427.5901837610237L234.70375955230958,425.9865251008091L235.69127167781167,425.55135979003535L234.77463107181276,424.26055011470316L234.48025307100218,422.1917536220444L233.69801933462261,422.60013003968936L231.3395518567327,421.7501370201386L229.34298326305895,420.35935921518603L226.01257642774002,420.1534055532968L224.43937323438277,416.2613156256508L223.3630142983979,416.15199084896665L222.89371784844718,414.4778562708143L221.81682082920352,414.42891233170656L219.61894191292163,412.84817846224075L218.7965555927976,411.8799374131164L216.383276211309,412.4259269931979L212.75362789275968,410.52695640603304L209.05996318641832,404.18608044316966L209.173766555224,405.9331483671175L209.93605289177822,407.24232170076846L211.97824741773323,409.5333921326054L211.89687318104785,410.05987366918635L213.42796277117165,411.99298154955386L213.85762890411823,413.4934216454751L212.75038535234228,413.5568052173667L211.3408581731135,412.2530754149618L210.20363834739172,412.38371452981175L208.9128213439945,413.3693503547073L208.06293216019893,411.04530444995635L206.44195871525548,409.4431284090691L205.8599871127283,410.3375720973205L201.91440849668743,409.46023766946325L201.85289396449912,410.1559738801624L203.8384068341799,410.16651025645774L205.80023198300842,411.2812579321185L206.3493959909371,411.13762336468915L207.00120723027658,412.36831547513066L208.26809003382184,413.6132576400556L206.82017008663973,415.1381404861388L205.57874640922637,414.9835138641107L206.04705075722623,416.3439005042104L204.3159994144258,415.81266696025034L203.59028204279636,415.21889629512987L202.7446685888052,415.52362252511364L199.71471693258175,414.40127173448764L197.39712538876523,413.25864027188925L196.87234379088505,412.28299009372404L195.40078768982715,411.08446954176213L192.41701091573586,410.8767909926188L190.59224467239005,410.2073702332789L187.6415522210936,409.7121357333208L185.57947029993227,408.977718280319L185.28505616815067,407.56155141834597L185.89226371840536,407.85265610448084L186.16383787788166,406.7999131523885L184.9882000098179,404.9987957158943L185.32127505038028,403.68468908941634L184.83753638678417,403.29496031705014L184.26839944115284,405.76906989635904L182.11051764802693,407.9438704195543L178.87112419805698,408.375832473634L175.90765712483216,407.8594443319698L175.51192212472196,406.8948659884485L174.36445770476598,407.4608585206155L172.86886282975252,407.103104217583L169.79782871831634,407.2276364817068L168.10358076051082,407.6194800339405L164.4645329727727,409.15186212540186L163.20460990818134,409.8816552161976L161.1319325517615,408.84778841400953L158.84310731818147,408.6837118223125L157.97050669561645,407.94200166386247L157.37041246846945,406.48564696359733L155.9401872664786,406.9329113235682L155.7501794466849,408.3929774820946L152.7598378039035,407.17010323405543L152.17633153382178,406.4721322697608L149.8165767772133,408.5042508850753L148.8753291300382,410.52096080160925L147.98781189432276,408.9977551583071L148.3564602375365,407.9826497052479L149.17509252603347,408.04943793556356L151.45687910991353,406.33288237335296L150.93502542762627,405.502610845337L149.8521994131464,406.20281516172486L149.13898490617197,405.1168632689655L148.0102542886055,405.1739354444029L146.3128526073358,402.4054302319129L146.05308011541223,403.22102945609447L144.6073754662264,403.9180683870766L144.04017430662924,403.61799108601724L143.70788408021474,404.6790057035886L141.73216175218812,404.70169228103316L141.85044864766277,405.7923243414348L140.613920452936,406.31276480207305L139.93863982071358,406.02558670470626L140.02738945693483,404.02031602761156L139.49248622135923,404.1755350418799L138.9815315486544,406.3721287361402L140.31174522047004,406.8357457671558L140.68873520262986,408.2887027172675L141.72499693167146,409.73828108279747L141.59107866665136,411.5186550457836L140.5138028922534,411.1283187967176L140.38710565804794,412.02828175407785L141.3974811206068,412.1975307145244L142.3423993573953,414.3662319620644L141.04584359237091,415.06875642939815L140.205275881796,414.7502758769315L139.1029071601881,415.5856660857253L138.3949985172438,415.18160081209567L136.7980242139788,415.5091091285593L136.71276794384585,414.6478488964626L136.0463643599999,415.34142455878623L135.7992419106085,416.49016089746965L134.96514770790662,415.6336053169945L134.33456678734197,417.133297754085L134.80245283356538,417.700254373372L133.73421095917868,418.68439373381887L132.66981799122667,418.9649171967251L132.4060860626002,420.1113129455746L131.37716002604648,421.25466796904163L130.52450138222534,421.03057457261036L129.79884085893363,422.2983816572961L129.07175620943207,422.343307050656L127.89450579518962,424.8890309420351L126.29411013344586,425.27768420986297L125.67543087105679,424.60396288958304L124.85088993856681,425.9868890557742L122.6978445399923,425.2685147908743L122.94444582151218,423.4406632226768L124.19181284560597,422.6470242775772L125.0700337477798,422.65080843076043L125.24013767525078,421.93221369490846L126.60695997075976,420.35796008029297L126.5105984030025,419.2091567278245L124.68434428731277,421.017248991751L122.880270982527,420.3164117232801L122.6027363373698,419.7125741287091L123.12893437459971,416.97847172863055L124.32815857651359,414.9099565560757L124.35212736861561,413.33923732455105L124.73476783609925,412.9987100908029L124.68371955816693,411.3213316495156L123.72171839582845,409.58942502486116L125.37415544016059,408.6731172339104L128.30672260082432,405.58701689169095L129.25226179294106,406.49564345081114L130.31086375196168,406.6284357847369L131.65268118737794,405.3159947277221L129.76893974344574,404.14844971945513L128.95387142283693,403.16439562268476L127.66530335517359,403.46954822391865L126.66748046167693,403.0889292080898L126.45992393753087,403.58333118803444L125.00902303777727,404.5396348820435L124.49016540734004,406.06187871485065L122.97099027311204,406.60992242526595L121.5556778203981,408.4719039696222L121.52413331708107,409.57803340320766L120.34542500930907,410.30145147975406L120.21057126736603,411.5351741564525L119.40504054492585,412.3835512806297L119.22938570640088,414.54829581409524L117.63640715794952,416.1179182222771L118.60591271990228,417.11078727377935L118.07429209643348,418.79196284100726L116.45284742388692,419.25639239795055L116.52680889421379,421.33259205059994L115.0526717881514,422.23645952922107L114.4786561002199,421.4259262477467L113.85946828767328,423.10625194727766L112.94235594387911,423.2517043486446L113.22392494417403,424.3815571202109L111.230438384625,425.2581615100345L111.10078918985866,428.4477947320422L113.48679661002467,428.40404040004216L115.44473495570521,429.08145858385103L116.07672747724222,430.05918622282525L115.4767791265192,431.79662061004103L114.30471022305437,432.95136611649275L113.1243311284357,433.119868513837L113.08989379442482,434.04766667677086L112.34773781869448,434.4616685405747L112.80873540624091,435.57562368781055L112.15459844502232,437.3672004101396L110.54833619358283,439.12214874083327L109.55341718717581,439.20393145410173L108.63327401359948,439.85417837631223L107.68812103673979,439.81145454539035L107.00966009961653,440.49661968861824L107.28531381590093,441.3414567097427L105.95268445266484,441.899219782743L105.76730831907923,443.18071600158646L104.76838515558694,442.44195486967715L103.89279899973592,444.9779382917237L102.13644239597846,444.9139249581551L102.33807997100472,446.22688839890657L101.2734392001622,445.94358892327L100.56806686494404,446.5591390897155L100.66621284612059,448.33889711514166L99.63499759151642,451.15753596894217L97.75150540263039,451.5960324335032L96.24674623001431,452.9293513924821L96.02552047097554,453.62903478005023L94.9839349980436,452.69373069634196L93.38812285928731,455.3986230639746L92.8905392064952,454.6682888991951L91.95487187474286,454.9287627885344L91.78067235970173,456.4288598847286L90.81807737853096,457.03203722654905L89.64220821631967,456.8335184373592L88.75959682973232,458.3487977028901L90.39020150659358,458.7679344074327L88.71769595501428,462.14139044113244L83.66440047179269,463.3129233602699L82.2670899070764,466.25136471560165L81.90780554885623,465.6218645772133L82.09194529207994,463.7838563574785L81.09356497887973,463.50086590732826L79.83919151462636,464.19132069439524L79.64523429010659,464.9375017254266L77.66933938915747,466.1361934302777L76.81649987588953,467.5076922309876L76.56513916500955,466.5298726049558L76.03509952333657,467.6727785358239L74.87483076527884,466.91325990041L72.66859528494471,468.6576258704199L71.04089185684036,468.56666961596625L71.29934966725676,467.19485361995066L70.61679229994495,465.8587070937174L69.94191617667217,466.9328628458361L69.97764547787662,468.08191528550674L67.68982267551466,471.5185514111905L66.96327994001041,470.6345042274895L66.69001836218091,471.9454932208856L65.18742587315896,471.66286048432744L65.03560996365127,469.5905491224877L64.13960976486405,469.0963055943853L63.78293523948808,469.8283320326793L64.56427792517715,470.77811629990936L64.11410266703209,472.19548746648445L62.86591249853855,472.8900400365328L62.01645240529106,471.24512481008776L60.90700460221845,471.0785460291959L60.67974057780412,471.69926387052203L61.754202214452945,472.66856737140427L59.63818018422579,474.05908787933606L61.006439632730796,474.5281297454736L61.00700707835715,475.2169241716924L59.87366588936283,474.6450779928873L58.245001445693106,475.93795941207645L55.229617322377926,475.7061498056087L53.67768644598533,476.52664206691884L53.49970518367013,477.204234698566L51.71306991513582,477.8872586613594L50.46708501749016,477.5108520697786L50.178237802429855,475.5355637182863L51.482717329262634,474.99805176731184L52.603799804554164,472.71980143136284L53.85850612326877,472.7464721446938L56.64915449887091,471.3682885768716L58.81766749583433,471.4322158129953L59.561755222950765,472.964254102788L60.24156164818547,471.90745541529236L60.173103583168114,470.64058300387705L61.44431770168135,470.12772633518364L62.78523340082907,470.1882004838651L64.69127677789858,467.5101500706568L66.75658602320233,465.11558904223455L69.3993632424811,463.0136452114524L72.43755387912617,462.1081566295634L73.67973534854616,462.5897805226389L74.90712673598557,461.97608606653137L75.21614165399308,462.8988317530917L74.52742881870581,463.9233438919081L75.25808471701613,464.73669877639077L75.49847598061534,463.47641409664413L77.01063030145505,463.37610413417156L77.42322452949641,464.1828544493119L78.35618789467479,464.4749506699545L78.39244860000083,463.499085612316L76.85593164308108,462.6284161336315L76.73242923581283,462.05315804800966L77.77319636112922,459.3611558511942L79.14469238859526,457.8156147475647L80.97874161470217,456.32153186266817L83.86917226022082,454.9815488675232L85.94677608036886,453.0580840205431L86.96081877898787,453.73063395466386L87.77003926787428,453.4275330998048L87.40186266089617,452.2276673968181L87.62844821794707,451.07330594683754L89.15713388104895,448.62402830019187L91.27516676937476,447.01314215550485L92.92760204387096,444.8881003094465L92.79600268239363,443.7416988653018L93.85707407048253,435.52827651824134L95.8500103331564,433.25759025282014L95.53783396204436,431.54301888420343L90.65008897854563,434.1975608745514L89.06655816232157,433.9530117610851L88.65525849000136,432.9269212616657L87.75624363537108,432.48693145774314L87.43633203351018,431.34237186063126L86.6493173656592,431.8759421172051L86.17759687275296,433.6687598092925L87.08262345851125,435.8968511672206L86.05310152897127,436.89386488715536L85.11939549285964,436.56293636194334L83.29060270892798,433.01608006988147L82.0649563551798,431.2410189594806L81.44554732523248,431.24405876818764L81.03642001278662,432.5692351711738L80.50385221768478,432.8005793809772L79.70489217316974,431.7073053964799L78.7308788505604,431.5325105048429L78.29661731732175,429.74641834311615L75.39228860574606,431.73533341487655L72.7642703023737,433.13099790511467L72.5400321139266,433.93228696810297L70.4577615295518,435.09207937466476L69.47606273670709,433.9709704290349L70.43116320185658,432.7310362542257L70.18778446334628,429.73045793751055L69.60546215614755,426.54668438596013L70.97848104550737,425.2599978290242L69.95263722689211,422.5829526497397L69.05002593540131,421.05821636505414L68.37859497580837,418.8474453051465L67.30213246569588,417.8877410452683L66.94660820310749,419.7757019246628L65.58810621629034,420.12515638415607L63.387260442350026,421.2370138240037L60.77880472268529,421.62147934014934L59.37936080717607,421.4260354271555L58.21433078965693,420.72048215918187L58.17645122536831,419.04521109773873L57.185112934220086,418.4618689402363L55.72700206453303,416.0536577529981L54.405902565375655,415.4955825610733L53.02789632977994,412.84847972078705L54.178884211261774,411.78322078612166L54.56277714827784,409.6760927285842L53.723193099775735,410.07347398756644L53.715717307416675,408.744704449005L54.18695963228255,407.68425125773933L53.24598332180358,406.62840885618687L53.05280932310794,407.6524455210323L51.84711673874723,407.1485923251686L51.83303542967771,405.3564273540603L50.8956580752819,405.0443599185695L50.48394770529646,403.7942858049637L50.64430141623694,402.30603496186984L49.632167237644154,402.9077506043491L49.602058586998005,401.45980408008154L50.795618446916336,401.2215559762592L49.997754907162104,399.53108859295924L51.67470193292291,399.5655632024061L51.84408982985829,397.6161529409479L52.357897073849145,396.3319809374624L55.738742897291345,392.3914841315427L56.46333170890274,391.17675104421744L56.891929596503275,391.43892282895547L56.76056756707534,389.6413913223589L58.12006249630663,386.6830030578492L59.18177063579445,385.54523005369856L61.0401791851437,385.1452739156058L62.424466841208556,385.744708080299L64.31530827405747,387.68776846038213L65.62115920033915,387.5199896620999L67.47922213640217,385.8156554367781L69.40009288954778,383.1832770625515L70.32828858531542,382.9261251353322L70.53685176160045,383.6226560250674L72.73597483979809,383.6819734472274L74.68955870751854,383.1466946429713L76.45814556079058,380.355773030873L76.46610574123197,379.6663114547681L75.64579479149715,377.0129297984872L75.5684602202564,375.46100891409424L74.28075693806723,373.7739263926484L73.81533853554485,372.32924597025726L75.13928522613472,372.75558607509356L76.41213397303049,371.5681145166436L76.49939301024996,370.4213220820176L74.92035864314327,368.2754050790809L73.69415991653942,369.9158416147037L72.57723848795254,369.6029910811542L71.50127900424451,370.4925053863078L70.29404986251532,370.6851577622932L69.97879871907281,371.3063221839999L68.56881098080922,372.1745230986054L68.08873844043512,373.7069455662561L67.3692423904908,374.3096584993717L67.12590249798446,372.46052090945204L66.30633386616563,372.0218602676998L65.64705324744851,373.42766523256034L65.33460594407224,372.7228131326584L63.8365687882925,371.6108785124444L60.6632480473379,371.4793390752543L58.32058818059557,372.469089742813L57.44501369103085,372.5770057444188L55.652187489811695,371.7452041451844L52.237054778621946,370.6395306216666L51.391423499717824,369.9250375686447L51.07668603438158,368.8566204847931L51.53156423381672,367.45979623283745L50.416985068105944,366.138978299335L50.78988626076404,364.8508253725978L51.62549767200632,364.2420872217406L51.54868956071331,362.5641155026186L50.33351604478093,362.441896512218L49.38159735258586,361.8814444320411L47.47133016842732,361.32611576772445L46.550733586425686,360.3551685365959L45.09455960404972,359.31578213053L45.08569218813011,358.21819654861235L47.66694086975968,357.08200086462796L50.95494443182368,355.02076581751476L53.20401243237817,353.80679583400763L54.333137220231805,354.71683669215133L55.547316132509195,354.99736207394903L55.9237537869747,353.88129699411365L55.19926703061448,353.6458287754426L55.215994879741636,352.6711028964761L58.26526393940958,351.3191606271165L61.621597187965456,350.3583962900318L63.38636517705963,350.35541965297796L64.32252940895953,350.8107506668914L63.71963700383523,352.494023712106L63.8344574928994,353.7037053012797L63.41428488201879,354.53870256397533L63.962048314493416,355.9459908340856L65.13853108578263,355.78112947341515L66.59404932446098,356.08318543284213L68.30684208113931,355.8728830749012L68.7753197551714,356.40735035706746L69.89088296228266,356.5639592372379L70.88771085773308,356.0824860491837L72.1533075250214,356.69298357656623L73.44421964316095,354.4364720092922L74.3267089691382,354.3412549515846L74.92046056192139,354.8103313452773L75.24431358475286,353.5002391631797L73.57370969909314,352.8376564170036L71.94692228029379,353.31035972004054L72.15677838317036,351.60036173304854L70.95569474113861,349.73407863448585L69.61090318002883,349.1150283394368L69.26676865706513,347.44422161523096L70.34245032376064,347.0843138715446L71.64563259793411,348.7841613023114L71.35492197601275,350.089874047628L71.98655245829384,351.13802696938717L73.40029930586621,352.3760670493068L73.77338887803883,351.1266882931824L72.17252018857864,349.4283098559474L72.95439960798564,346.47874317867536L72.40609818537253,345.950098976248L70.79026826041347,346.52852041819335L69.15404996461022,346.2970053024336L68.92754120943138,345.77374925580636L68.07459494108026,346.25193497690736L64.70584642510535,344.8261140123343L64.71293494911698,343.5122067369831L63.86448102158234,340.54971430600256L63.11855849169238,339.4187701521121L61.887479319832394,338.42420541766444L59.46309737650637,335.73470914632026L58.35415747930855,334.6749332534498L57.18995255865458,334.34740372016086L55.58722256745155,332.48878377982953L53.97667317214224,331.3607512563317L53.925998116680546,331.0129593224449L55.24912071574059,330.6298521356938L55.97042036192422,329.10118154181225L56.30952738118713,325.94179943118513L59.66487776388425,326.46185420767017L63.80207296237138,326.02196580989687L64.89786872278847,325.5220646691499L66.66548477718969,324.03325570005404L68.37010032001055,321.68160223702955L68.80811403332623,319.26803245757935L69.56619477132229,317.2098074755088L70.99762717973721,315.51657396067424L71.62138248625352,314.2414938261828L73.34679504057625,312.2104511816847L73.58754174091024,312.7802811315761L74.96493698499845,312.98222402363956L76.9923796256535,311.9464648613159L78.25876256751204,310.83371103506977L81.23400985839561,307.3529685561391L82.35046653159014,307.17600780056114L82.47138627292732,307.6800176855463L83.60433195235478,307.2722985775897L84.72434175569865,307.3646296861381L86.90870243290567,306.861066319527L89.00424516974104,305.27392269214806L90.97426842801902,302.04885643037585L91.78735685237075,301.3361733420418L91.96689726934937,301.88695949478995L95.27070036608688,302.98000962232743L95.59610666019347,303.8563713281816L94.54931007091987,305.104257780803L94.03714703470673,305.19204960257116L94.15140399183349,306.7588057162758L95.77062825279462,306.1486697651485L95.80924823670175,305.3026711033931L96.49849920923158,304.4676910511828L96.77846551351413,304.8971750578738L97.19762471891524,303.0682340418906L98.93864320048482,304.561576697988L98.77136007562432,305.8131376727009L99.81481659085163,306.0643313331817L100.47292605104222,306.73980841405717L101.24973123726251,305.4868073523361L102.79287429482957,305.2838540346713L103.6317615347323,304.8051084020369L105.92443445029161,304.9544007114116L107.12115941986896,305.26911582867024L106.84199633760183,307.73234636776067L109.04095769524557,308.09280992234665L109.27209054938419,308.6873735226842L111.4869466258165,309.479374247398L111.43936300079697,308.97485094061415L112.83988670983771,308.10204522315826L114.27860982196681,307.9529110473079L114.37937715409225,308.5066040914495L115.22058444023064,308.4388457087489L115.97224775744844,307.5282625218057L117.38150340980206,307.19333325258754L118.43770995150585,307.36380792851287L119.9476652101524,307.9665155218253L120.55657543504134,307.6906194534539L121.66993346842578,308.6953754000248L122.11377041410307,308.15876984025283L123.02556700821344,308.33661022325725ZM118.95669800533585,438.6690016886761L118.97538252893088,439.1298422883532L117.00602034440264,438.64058676021807L118.07783784422375,435.8114861176846L119.27755803368711,435.45185455856745L119.84038455291557,432.9009450364649L121.00539061234893,434.9706061041252L121.69425103884215,434.13877751237294L123.32438048169612,435.1635390020748L123.52288311059067,436.82022362819043L121.36133605173757,437.30430439856093L120.48387282311182,438.1555271937465ZM113.8172044415278,444.3215709809134L115.27548630039246,442.7991280315555L113.81788154331615,442.64671849191177L113.6773325870123,441.44666719480585L114.78431494104888,440.5347463702758L115.68717061862702,441.02596556293406L115.9255357685517,442.2163655237383L116.33275463207184,441.3672976949714L116.18763431540107,439.5897571388349L117.2952403436324,440.2880560661987L117.3597129484499,439.12501799212055L118.3358587339871,439.71802244932576L119.42270238338953,439.60259433506826L120.19856807156054,438.88160459477126L121.7077408461802,439.8124337669959L122.0526749558413,442.841254735643L123.79129905239145,442.4074423501812L122.86630102686516,444.5423261736912L120.63631866633253,443.9833253103086L121.57748658781739,445.2097351592005L121.08415172254041,446.3637063474314L119.92206804189044,445.96951479788584L120.1118140855896,448.03079704568995L118.47163050209791,448.7807662144445L118.00130691250449,449.6953541182038L116.86790460352054,448.99950831157093L115.96019716802097,451.28173014828803L115.10920840704784,451.5926749858709L114.26182227053033,452.6514286464784L113.70794129194545,450.3352626754139L112.51110866497606,451.7096102193101L112.38485606661976,450.97051259475063L111.14047650471575,450.32544787899735L110.87257411403587,448.21330115460955L109.6610942578533,447.4460503623477L110.10870685166353,444.9296434422555L112.2089440069378,443.1947334033789L113.5907976076137,443.187213507214ZM111.41380022592772,454.39725448896843L110.38836934331547,456.6130021971186L109.98237747303563,456.2992461516752ZM105.56511196370863,461.9729033195699L106.50172762158988,462.0252246433964L106.32808090865649,464.2236688499188L104.76335491953486,464.0383703900237L104.4589964467774,463.30977040331095ZM80.65332301389044,469.5283980625783L80.2958012090944,471.76616436704455L78.44977377461629,473.59856310821715L79.34511472216518,470.7905620538553L79.96748196168578,471.0779313203757ZM76.90452039375856,468.71351948017525L78.01245674568962,468.72064573865305L77.97400307732762,469.86800710373154L76.85285851496894,471.12284055190173L75.87826915774987,470.2533780310365L75.24712283456545,471.0495164308817L74.91165443649155,469.09457572087445L75.24542764301592,468.467492548622ZM66.44251510149047,472.4536337329117L66.54322710706963,473.3751579089817L65.83058285842203,473.9243311230325L65.3381111913204,472.93106748878506ZM68.79270071643758,381.6090322382279L68.06693794397843,382.617064948888L67.8737357224421,381.6892548969563ZM62.935755354838484,477.4837005338477L64.21926152661318,477.93737046770934L64.05206825439622,478.79108811013657L63.01859141592166,478.6917379328796ZM46.09973898931016,478.4328785503167L46.43468641923376,479.6680510376631L45.45341677888785,480.1031921338937L45.22592989006058,478.81881102015143ZM44.80273557634242,479.81737118725135L42.82285692768954,480.7913726599144L42.493591837018755,479.95585898308553L43.39072121849459,479.00230227443524ZM47.21568734898585,414.6498540021263L48.43440464247717,414.3600616738604L48.6188691774534,415.1287100354908L49.676470506874956,415.0508295690694L50.63130841000597,415.8277099250628L50.574647843064895,418.8275832440821L49.9490721508664,419.75610667327965L48.55550707838431,420.21038183022824L48.175187258608574,421.21628678843956L46.30904396356889,419.8835625075575L45.38954602522041,419.85073241356713L43.57707204288297,418.1596169095942L42.8951355570312,418.08685156723686L41.85421143212331,417.10425719649777L41.6117009825099,415.68685955759213L42.21396869603426,415.406359307652L44.09543472587955,415.9564423366028L45.11030438175925,414.9617762827197L46.07903522929137,414.9436791137297L46.57442368241127,414.2405037192061ZM40.77546056740219,480.9444932596792L41.70854604288131,481.83858089066763L39.46371982939579,483.5781396875342L39.46376464225174,483.92330473153015L42.20193513448808,482.7471713343975L42.162009320801566,483.54848190120117L41.02211994820056,484.41928626057796L39.26633680314338,484.88166184562874L39.00044949368438,485.8330458625388L37.058471562540724,486.67092182598094L35.451514733514024,486.5582680208643L34.289082589522835,487.4098299071588L32.2119048479147,488.03892794931494L31.25965413047745,487.0063604991544L33.46189130189373,486.1660375757058L34.08945620131835,486.40906715943976L35.75361569819973,485.66989456796773L35.490718937389744,484.6053697677912L36.48690349487871,483.61831914948755L37.75320097126303,484.26865759463635L37.95874432409362,483.5991940607849L36.56297536957032,483.2234017526667L35.865938808845854,482.4002615405897L36.67344253853362,481.2197837674632L39.13536340461122,480.72568443971096L39.497826185781165,482.20064221568407ZM24.811019300386178,488.09948360933384L27.4576371493717,486.4250289238172L27.70190412003989,485.5909086568081L28.73978836977883,484.7409730677289L30.219293075636507,484.4615293182697L30.903810565519606,485.0626240221787L31.013488091374107,486.4587273247805L28.17391078056186,487.61103115231026L26.462739141205383,489.584631118881L25.19955553637714,490.1698738883612ZM18.43317054959109,489.97510424732025L18.55806304935954,491.03363563508657L16.931929679456843,490.8488678087309L16.862669473754373,490.14462096447085ZM22.824051228074396,444.8185835732139L21.908026070038794,445.6655666734438L21.905764710182687,444.67599059260283ZM12.341076773204946,491.11344218393873L12.599861475035041,492.1393133003671L11.315614795399426,492.62530021737564L11.309607271072522,491.5820492118259ZM25.936063514010733,376.15875438392425L29.303407518049404,378.3142489427106L31.6234887328515,377.35275861371554L32.557962894170466,377.61642921655414L33.29752858993688,378.48674294601926L33.33333153048367,379.77135262666263L35.077674256285235,380.7292606058078L35.57002065957232,381.4397676622932L37.944453521094694,382.06321360645427L39.3350148651159,382.7134950921777L38.33844438139587,384.1471246926958L37.20776538423485,383.6450855019642L35.91470596512506,383.75426930464187L35.17680361367698,384.3456662764859L34.362855524101356,385.7964632281621L33.67391936246262,384.2414650782565L32.77121955700364,383.11671034488813L31.81912889934103,382.85355638353167L31.529845626728466,381.70255420614524L29.41825325715771,379.9646544712208L28.34165372507305,379.72667345958155L26.468754936096943,380.63026603232004L25.31429902024847,379.784386392423L25.008582078519368,378.4446745125339ZM0.6832226140747082,492.3134085890534L0.563896431125869,493.511493874375L-0.6909631728934613,493.50477091268846L-0.2551385204127996,492.541661754799ZM-7.343541079186551,493.2798104283275L-6.604858685057309,493.8992008147017L-4.235212132096947,494.3222803388352L-4.198272092236962,494.6789799842175L-7.113384544788261,494.61024682072514ZM-11.441146947694094,491.00334577415714L-11.255496635179426,489.9916073400338L-10.27767292659901,489.7955621852112L-9.222104117196764,491.0744904641046L-9.908051851561154,491.92033992618485L-10.654803237454786,491.7007234298756L-10.642677358754398,492.81332639583184L-11.876817916905424,492.6614833373061L-14.683900644145098,493.2066751496668L-16.060243840925637,492.542379109339L-15.46774046064263,491.8580728795498L-13.939818888480175,492.3208929454807ZM-25.978216687361638,492.14607218044745L-24.797148588216047,492.26687164037804L-25.115791004149898,493.5399089223126L-26.527632720653557,493.00741347283446L-28.710844564036307,494.0378627503976L-28.886822699010438,491.87055496854674L-28.11346988840178,492.01218671048014L-27.62486518700102,490.54703723361587L-26.682015092287585,490.7303533557939L-26.964809165637035,491.8361349565483ZM-30.039522844298688,490.09340665089275L-29.48276207412168,490.7711337001049L-30.415313812755613,492.3547869125737L-31.51405521108181,492.5948418490405L-31.269758155095488,491.53820664736423ZM-36.18430045430438,488.7176415151889L-35.13785473735733,489.0683103404588L-34.51058971427021,490.54360289592887L-35.93816487574573,491.6883269272745ZM-85.41868974767752,459.51595326891925L-84.6044383846818,460.6096519182688L-84.96555302676487,461.63641191052386L-87.54818537321603,461.2134050275213L-88.39466087323785,458.97564529728527L-88.07415471140806,458.2421246790691Z");
        },
        'correct css class should be set [California]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state")[0][4].getAttribute("class"), "state california");
        },
        'correct css class should be set [District of Columbia]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state")[0][8].getAttribute("class"), "state district_of_columbia");
        },
        'correct title should be set [California]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state title")[0][4].innerHTML, "California : 154");
        },
        'correct color should be set [California]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state path")[0][4].getAttribute("fill"), "#0089FF");
        },
        'correct state boundary should be rendered [California]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state path")[0][4].getAttribute("d"), "M158.86749327536552,136.57366253041232L169.52167318895334,139.31963086623898L186.19551014223396,143.86530095759917L199.15490385060787,146.9946542518245L192.2385362157263,176.65145104379587L187.05464324980534,198.3282616942223L200.48783880999213,217.6366012019521L213.48995630613223,236.32410714790296L223.96848858783574,251.3499247917456L231.6362486480159,262.3695348585253L245.40165831056862,282.2495598143262L245.01556926091882,284.4329691425735L246.81464151790698,287.6856310964099L247.94295916820315,292.57788879372083L250.29387365892035,295.5255789239701L248.20173523954162,297.5116760443086L245.76079578294045,298.26119692369184L243.52522270730825,300.9987492948677L243.35283864885847,305.17243360540465L242.51431242596587,307.66435706785876L239.19377214738782,309.6188895797653L238.98897469033386,316.22796129434414L240.9328214351707,316.66850734379307L241.15333727561176,320.0273941815818L240.1009005889386,321.40501255359516L237.15011672279869,321.56712919774793L217.8161823002992,319.652944256969L202.04033014274722,318.09589048968326L200.77723598497573,315.48218480793423L201.43403390846214,311.8865753665174L201.21417691290952,307.421865221457L199.81542876831804,303.9879494431257L196.26295534375987,298.91689801055895L191.4463426181942,293.85280948580635L190.1426873234451,294.6547338804488L188.12604924245852,293.52681486214874L188.8034744040483,291.9005524464983L187.10481084314512,287.8810253013743L183.63703016153994,287.9033282659451L178.38058338274737,284.05646189828144L178.00908069881905,281.79850995660865L174.69769148699118,278.3704760581802L170.25618828800395,277.43650039638317L166.8679169214119,275.4496100304908L162.117333105974,274.8091326043782L160.23105140624904,271.9732943380184L161.92047035865937,267.3250055534397L161.271224070754,266.3737528428197L162.61866486179377,263.12945841373175L159.62415971754388,259.7183324587346L160.32546846101974,256.21641512579856L159.02274144168632,255.69686428680927L157.52049811722304,252.14490541943132L156.11542797435885,251.0986875176859L155.91243827162674,249.05916432933486L152.4841790556901,240.72974975508077L150.5689397862028,238.048594357473L151.4703314514116,232.40171979858405L152.3806859202512,233.13375594631304L154.1744441307638,230.10627553657207L153.03460450272132,226.62559339721565L150.594406909506,226.39422279379642L148.22844124356055,222.88545143368754L147.69717654472532,220.45106923426533L148.4550677196413,218.45455910856822L147.64108859357492,215.34576349861663L148.82302555496062,210.86566913678314L151.2831620054618,211.51212438240805L151.91261122007654,204.99108705340188L150.66056257722164,205.3604189499216L149.6322658908984,208.38365880317326L146.86029733498947,208.34863212195444L144.38296937637767,205.18863484893325L144.9571504514007,201.04488992572863L143.80562208687257,197.33478851913344L141.69260703297857,194.65969031915552L140.87745589484786,192.0349259671931L138.24489647040554,186.60263027690235L139.24416249981272,185.47755865590432L139.05257872072264,179.3144984884458L140.70688341610975,176.36934888725682L140.9034113113686,171.3162560237522L138.92030848004458,165.75088285973197L136.45303019315753,162.24503392999543L136.70028929481128,159.0062247427985L141.9878200433326,152.4889917563014L143.31462792572376,150.15919033729665L143.24514751784722,148.03665398793316L145.84877141065436,143.26445568149745L146.13061774898807,138.34008150911268L145.08288442186478,136.84266601428135L146.67634556546574,133.29105306047552Z");
        },
        'correct css class should be set [Colorado]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state")[0][5].getAttribute("class"), "state colorado");
        },
        'correct title should be set [Colorado]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state title")[0][5].innerHTML, "Colorado : 22");
        },
        'correct color should be set [Colorado]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state path")[0][5].getAttribute("fill"), "#E2F2FF");
        },
        'correct state boundary should be rendered [Colorado]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state path")[0][5].getAttribute("d"), "M350.6558279386644,190.32747464076294L379.1417564600954,193.0766804542833L400.9842673748395,194.56648090187275L427.0604847196623,195.95426209201173L426.3080372819032,213.58455343256014L424.19976347803527,266.528981419205L410.9873725131713,265.80322990122784L392.5653612831207,264.79968603721807L357.74429102638516,262.0082268758514L350.15212938381376,261.1785078704979L327.9017732133032,258.7738487371266L330.28515677736027,238.3522923152061L330.287518840727,236.40886491926926L332.0973188488354,221.55788417132146L335.99623347504007,188.80082044863843Z");
        },
        'geo layer1 g is created': function (chart) {
            assert.isNotEmpty(chart.selectAll("g.layer1"));
        },
        'correct number of counties should be generated': function (chart) {
            assert.equal(chart.selectAll("g.layer1 g.county")[0].length, 5);
        },
        'correct css class should be set [county]': function (chart) {
            assert.equal(chart.selectAll("g.layer1 g.county")[0][1].getAttribute("class"), "county");
        },
        'correct title should be set [county]': function (chart) {
            assert.equal(chart.selectAll("g.layer1 g.county title")[0][1].innerHTML, "");
        },
        'correct color filling should be set [county]': function (chart) {
            assert.equal(chart.selectAll("g.layer1 g.county path")[0][1].getAttribute("fill"), "white");
        },
        'correct state boundary should be rendered [county]': function (chart) {
            assert.equal(chart.selectAll("g.layer1 g.county path")[0][1].getAttribute("d"), "M131.19348249532783,331.15839361481187L134.96890954443043,330.37917634921996L133.88913955606316,325.4363177123538L152.64962091501457,320.56007808556967L160.4572887576888,347.1028290176347L158.0671840381978,351.9017106061042L155.0415797335442,353.5040635871427L150.65553443466857,362.3245894815043L150.3836157997208,357.96070178744037L142.96691427858548,360.3402214115232L139.6887863651528,356.5305270343024L137.8140206216504,358.3232381108978L129.55454916848106,361.03970849762686L130.7089240122412,367.30195283794376L134.05993594430532,369.50516128525805L128.5321389012008,370.28728091558514L121.73420032908868,371.2615742490283L119.7332703794522,375.24284238566725L116.3612100616881,375.78356435845217L115.88559341238928,379.48528537322454L113.09005261057385,379.85809927310163L115.58389710823971,384.6705431432749L113.43023064930466,389.5940776904407L113.90836230854782,394.1137969187374L110.6244284405634,397.21876016250303L94.36525329352173,398.3469122411177L87.1641399364873,397.6645386661802L83.60211149160186,399.50780328972644L77.36596470374718,399.5170645758535L74.9088762742444,396.7829139076556L75.97652856642367,388.3409398419816L76.7866610875326,382.8306764736957L81.3907054432508,380.1432220701678L80.20067355768676,377.44617694410533L80.09802522357364,370.15503846150125L81.87179153566686,368.31323717938983L81.76038280789619,362.0074894997733L81.73276958174162,357.4832740029883L84.39838510538878,355.73734184184184L88.93327086559063,355.57293734302436L88.8403228448861,351.9136076350775L98.70653234516956,353.20155133192816L98.72884703790787,350.4494738989057L104.0701473723203,348.4875903827698L103.8896632940189,343.86085564424445L101.36023362342851,343.0996266491818L101.31771046875103,339.4999452756672L98.53564918942395,337.8811219128646L98.56681109628813,335.53933807857004Z");
        },
        teardown: function (topic) {
            resetAllFilters();
            resetBody();
        }
    }
});

suite.addBatch({
    'filter and highlight': {
        topic: function () {
            var chart = buildChart("choropleth-chart-with-filter");
            chart.filter("Colorado");
            chart.redraw();
            return chart;
        },
        'correct color should be set [California]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state")[0][4].getAttribute("class"), "state california deselected");
        },
        'correct color should be set [Colorado]': function (chart) {
            assert.equal(chart.selectAll("g.layer0 g.state")[0][5].getAttribute("class"), "state colorado selected");
        },
        teardown: function (topic) {
            resetAllFilters();
            resetBody();
        }
    }
});

suite.addBatch({
    'custom projection': {
        topic: function () {
            var chart = buildChartWithCustomProjection("choropleth-chart-with-projection");
            return chart;
        },
        'should return not null': function (chart) {
            assert.isNotNull(chart);
        },
        'svg is created': function (chart) {
            assert.isNotEmpty(chart.selectAll("svg"));
        },
        teardown: function (topic) {
            resetAllFilters();
            resetBody();
        }
    }
});

suite.addBatch({
    'replace and remove layer': {
        topic: function () {
            var chart = buildChart("choropleth-chart-replace-layer");
            chart.overlayGeoJson(geoJson3.features, "state", function (d) {
                return d.properties.name;
            })
            return chart;
        },
        'geo json layer with the same name should be replaced': function (chart) {
            assert.equal(chart.geoJsons().filter(function (e) {
                return e.name == "state";
            })[0].data, geoJson3.features);
        },
        'geo json layer can be removed by name': function (chart) {
            chart.removeGeoJson("state");
            assert.equal(chart.geoJsons().filter(function (e) {
                return e.name == "state";
            }).length, 0);
        },
        teardown: function (topic) {
            resetAllFilters();
            resetBody();
        }
    }
});


suite.export(module);


